Difference
==========

.. currentmodule:: pqp.symbols

.. autoclass:: Difference
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Difference.copy
      ~Difference.r_adapt_map
      ~Difference.r_map
      ~Difference.sorted
      ~Difference.syntactic_eq
      ~Difference.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: copy
   .. automethod:: r_adapt_map
   .. automethod:: r_map
   .. automethod:: sorted
   .. automethod:: syntactic_eq
   .. automethod:: to_latex
